==> bokeh-0.8.0-np19py27_0.tar.bz2: lib/python2.7/site-packages/bokeh/server/static/js/util/util.js <==
(function() {
  define(["underscore", "sprintf", "numeral"], function(_, sprintf, Numeral) {
    var replace_placeholders, _format_number;
    _format_number = function(number) {
      if (_.isString(number)) {
        return number;
      }
      if (Math.floor(number) === number) {
        return sprintf("%d", number);
      }
      if (Math.abs(number) > 0.1 && Math.abs(number) < 1000) {
        return sprintf("%0.3f", number);
      }
      return sprintf("%0.3e", number);
    };
    replace_placeholders = function(string, data_source, i, special_vars) {
      var _this = this;
      if (special_vars == null) {
        special_vars = {};
      }
      string = string.replace(/(^|[^\$])\$(\w+)/g, function(match, prefix, name) {
        var replacement;
        replacement = (function() {
          switch (name) {
            case "index":
              return "" + i;
            case "x":
              return "" + (_format_number(x));
            case "y":
              return "" + (_format_number(y));
            case "vx":
              return "" + vx;
            case "vy":
              return "" + vy;
            case "sx":
              return "" + sx;
            case "sy":
              return "" + sy;
          }
        })();
        if (replacement != null) {
          return "" + prefix + replacement;
        } else {
          return match;
        }
      });
      string = string.replace(/(^|[^@])@(?:(\$?\w+)|{([^{}]+)})(?:{([^{}]+)})?/g, function(match, prefix, name, long_name, format) {
        var column, replacement, value;
        name = long_name != null ? long_name : name;
        value = name[0] === "$" ? special_vars[name.substring(1)] : (column = data_source.get_column(name), column != null ? column[i] : special_vars[name]);
        replacement = value == null ? "???" : format != null ? Numeral.format(value, format) : _format_number(value);
        return "" + prefix + (_.escape(replacement));
      });
      return string;
    };
    return {
      replace_placeholders: replace_placeholders
    };
  });

}).call(this);

/*
//@ sourceMappingURL=util.js.map
*/

==> bokeh-0.8.1-np19py33_0.tar.bz2: lib/python3.3/site-packages/bokeh/server/static/js/util/util.js <==
(function() {
  define(["underscore", "sprintf", "numeral"], function(_, sprintf, Numeral) {
    var replace_placeholders, _format_number;
    _format_number = function(number) {
      var format;
      if (_.isNumber(number)) {
        format = (function() {
          switch (false) {
            case Math.floor(number) !== number:
              return "%d";
            case !(Math.abs(number) > 0.1 && Math.abs(number) < 1000):
              return "%0.3f";
            default:
              return "%0.3e";
          }
        })();
        return sprintf(format, number);
      } else {
        return "" + number;
      }
    };
    replace_placeholders = function(string, data_source, i, special_vars) {
      var _this = this;
      if (special_vars == null) {
        special_vars = {};
      }
      string = string.replace(/(^|[^\$])\$(\w+)/g, function(match, prefix, name) {
        return "" + prefix + "@$" + name;
      });
      string = string.replace(/(^|[^@])@(?:(\$?\w+)|{([^{}]+)})(?:{([^{}]+)})?/g, function(match, prefix, name, long_name, format) {
        var replacement, value, _ref;
        name = long_name != null ? long_name : name;
        value = name[0] === "$" ? special_vars[name.substring(1)] : (_ref = data_source.get_column(name)) != null ? _ref[i] : void 0;
        replacement = value == null ? "???" : format != null ? Numeral.format(value, format) : _format_number(value);
        return "" + prefix + (_.escape(replacement));
      });
      return string;
    };
    return {
      replace_placeholders: replace_placeholders
    };
  });

}).call(this);

/*
//@ sourceMappingURL=util.js.map
*/
